@@ -19,7 +19,7 @@ basicConfig(format=json.dumps({'created_at': '%(asctime)s',
                                'log_message': '%(message)s'}
                               ),
             level=INFO,
-            filename='rdf_logging.log',
+            filename='logging.log',
             )
 old_factory = getLogRecordFactory()
 
